# hitfactorpy_sqlalchemy

[![Main](https://github.com/cahna/hitfactorpy-sqlalchemy/actions/workflows/main.yaml/badge.svg)](https://github.com/cahna/hitfactorpy-sqlalchemy/actions/workflows/main.yaml)
[![PyPI version](https://badge.fury.io/py/hitfactorpy-sqlalchemy.svg)](https://badge.fury.io/py/hitfactorpy-sqlalchemy)

Manage practical match reports in a database with SQLAlchemy

## Status

**Work in progress...**

## Documentation

See `docs/index.md` via [website](https://cahna.github.io/hitfactorpy-sqlalchemy/) or [source](https://github.com/cahna/hitfactorpy-sqlalchemy/blob/main/docs/index.md).
